from turtle import *
peacecolors = ("blue","black", "red3", "orange", "yellow", "seagreen4", "orchid4")
reset()
Screen()
up()
shape("turtle")
resizemode("user")
shapesize(8, 8)
goto(-320, -195)
width(70)

for pcolor in peacecolors:
    color(pcolor)
    down()
    forward(640)
    up()
    backward(640)
    left(90)
    forward(66)
    right(90)
width(25)
#设置画笔颜色
color("white")
goto(0,-170)
down()





from pyleap import *

# 创建对象
title = Text("LeapLearner", 60, 380, 50)
mike = Sprite("https://rss.leaplearner.com/Image/Role/Frog1.png", 250, 240)

# 绘制函数
def draw(dt):
    title.draw()
    mike.draw()

# 重复绘制
repeat(draw)

# 运行窗口
run()


from pyleap import *
from pyglet import gl
import math, random
targets = []
# Lesson 1
spaceship = Sprite("https://r.leaplearner.com/i/Fighter15.png", 50, 50)
spaceship.scale = 0.4
target = {'x': -100, 'y':-100}
rain = []
for i in range(0, 50):
	rain.append(Sprite("https://r.leaplearner.com/ud/production/A01T0008/EpZi.png", random.randint(0, 800), random.randint(500, 1000)))

# Pyleap确认
def confirm():
    window.set_size(400, 400)
    window.clear()
    bg = Sprite("https://r.leaplearner.com/i/background.png", 200, 200, 400, 400)
    bg.draw()
    txt = Text("恭喜您！")
    txt.color = "black"
    txt.x = 120
    txt.y = 320
    txt.font_size = 30
    txt.draw()
    txt.src = "如果您能看到这个项目"
    txt.color = "black"
    txt.x = 55
    txt.y = 250
    txt.font_size = 20
    txt.draw()
    txt.src = "说明您已经成功安装Python"
    txt.color = "black"
    txt.x = 25
    txt.y = 200
    txt.font_size = 20
    txt.draw()
    txt.src = "可以正常运行程序"
    txt.color = "black"
    txt.x = 85
    txt.y = 150
    txt.font_size = 20
    txt.draw()

def detect(x, y):
	global target
	target['x'] = x
	target['y'] = y

def space1():
	global spaceship, targets
	window.set_size(800, 400)
	window.clear()
	txt = Text("用fly_to(x坐标, y坐标)来控制飞船飞行吧！", 100, 350, 15, "white")
	space = Sprite("https://r.leaplearner.com/ud/production/A01T0008/o9hm.jpg", 400, 200)
	space.draw()
	window.show_axis()
	spaceship.draw()
	if (len(targets) > 0):
		dx = targets[0]['x'] - spaceship.x
		dy = targets[0]['y'] - spaceship.y
		ds = math.sqrt(dx*dx + dy*dy)
		if (ds < 150):
			spaceship.set_anchor(spaceship.x, spaceship.y)
			if (dy == 0):
				if (dx > 0):
					spaceship.rotation = 270
				elif (dx < 0):
					spaceship.rotation = 90
			elif (dy < 0):
				spaceship.rotation = 180 + math.degrees(math.atan(-dx/dy))
			else:
				spaceship.rotation = math.degrees(math.atan(-dx/dy))
			if (ds < 5):
				spaceship.x = targets[0]['x']
				spaceship.y = targets[0]['y']
				if (len(targets) > 1):
					targets.pop(0)
				txt.src = "到达目的地：(" + str(targets[0]['x']) + ", " + str(targets[0]['y']) + ")"
			else:
				spaceship.x = spaceship.x + dx / ds
				spaceship.y = spaceship.y + dy / ds
				txt.src = "正在飞往：(" + str(targets[0]['x']) + ", " + str(targets[0]['y']) + ")"
		else:
			txt.src = "飞行距离过长，请降落到更近的星球"
	txt.draw()
def fly_to(x, y):
	global targets
	targets.append({'x': x, 'y':y})

def space2():
	global target, rain
	window.set_size(800, 500)
	window.clear()
	robot = Sprite("https://r.leaplearner.com/i/robot_3.png", target['x'], target['y'] + 30)
	arrow = Sprite("https://r.leaplearner.com/ud/production/A01T0008/9WZr.png", target['x'], target['y'])
	# arrow = Triangle(target['x'], target['y'] + 10, target['x']-7, target['y'] - 10, target['x']+7, target['y'] - 10, "red")
	txt = Text("用detect命令控制小乐探测水源吧！", 140, 450, 25, "black")
	water = Sprite("https://r.leaplearner.com/ud/production/A01T0008/EpZi.png", 535, 250)
	bg = Sprite("https://r.leaplearner.com/ud/production/A01T0008/uH1W.jpg", 300, 250)
	water.scale = 0.7
	robot.scale = 0.6
	bg.scale = 1.8
	arrow.scale = 0.35
	bg.draw()
	window.show_axis()
	robot.draw()
	dx = water.x - target['x']
	dy = water.y - target['y']
	ds = math.sqrt(dx*dx+dy*dy)
	if (target['x'] >= 0 and target['y'] >= 0):
		if (ds < 25):
			txt.src = "哇！我们找到了水源！太棒啦！"
			txt.x = 100
			for drop in rain:
				drop.y = drop.y - 10
				if (drop.y < 0):
					drop.y = 550
					drop.x = random.randint(0, 800)
				drop.scale = 0.5
				drop.draw()
		else:
			if (ds < 150):
				txt.src = "水源应该就在不远处……"
				txt.x = 140
				# arrow.color = "green"
			elif (ds < 300):
				txt.src = "emmm，我们离水源应该还有一些距离"
				txt.x = 60
				# arrow.color = "orange"
			else:
				txt.src = "再找找吧，这里根本没有水源的迹象"
				txt.x = 70
				# arrow.color = "red"
			if (dy == 0):
				arrow.set_anchor(target['x'], target['y'])
				if (dx > 0):
					arrow.rotation = 270 + random.randint(-5,6)
				else:
					arrow.rotation = 90 + random.randint(-5,6)
				arrow.draw()
			elif (dy<0):
				arrow.set_anchor(target['x'], target['y'])
				arrow.rotation = 180 + math.degrees(math.atan(-dx/dy)) + random.randint(-5,6)
				arrow.draw()
			else:
				arrow.set_anchor(target['x'], target['y'])
				arrow.rotation = math.degrees(math.atan(-dx/dy)) + random.randint(-5,6)
				arrow.draw()
	txt.draw()
def sky():
	_star = Sprite("https://r.leaplearner.com/ud/production/687283/BwjM.jpg", 250, 250)
	window.set_size(500, 500)
	_star.draw()
	window.show_axis()

def astro():
	_star = Sprite("https://r.leaplearner.com/ud/production/687283/dJAT.jpg", 500, 500)
	window.set_size(1000, 1000)
	_star.draw()
	window.show_axis()

def star(x, y):
    _star = Circle(x, y, 5)
    _star.draw()



# Lesson 2
lines = []
ps = [[66, 88, 96, 134], [129, 169, 213, 196], [275, 204, 355, 187], [410, 171, 487, 132], [546, 139, 610, 195], [655, 237, 698, 293]]
class Line(Shape):
	def __init__(self, x1=100, y1=100, x2=200, y2=200, line_width=1, color="orange"):
		""" 线段
		线段宽度： line_width， 默认为1
		颜色： color, 默认为"orange"
		"""
		x = (x1 + x2) / 2
		y = (y1 + y2) / 2
		super().__init__(color, gl=gl.GL_LINES, line_width=line_width)
		self.x1 = x1
		self.y1 = y1
		self.x2 = x2
		self.y2 = y2
		lines.append(self)

	def update_points(self):
		self.points = (self.x1, self.y1, self.x2, self.y2)	

def check(self, x1, y1, x2, y2, ds):
	dx1 = self.x1 - x1
	dy1 = self.y1 - y1
	dx2 = self.x2 - x2
	dy2 = self.y2 - y2
	ds1 = math.sqrt(dx1*dx1+dy1*dy1)
	ds2 = math.sqrt(dx2*dx2+dy2*dy2)
	if (ds1<=ds and ds2<= ds):
		return True
	else:
		return False

Line.check = check
def space3():
	global spaceship, targets, lines
	window.set_size(800, 400)
	window.clear()
	txt = Text("为地球上的人们搭建星际廊桥吧！", 100, 350, 15, "white")
	space = Sprite("https://r.leaplearner.com/ud/production/A01T0008/nUuI.jpg", 400, 200)
	space.draw()
	window.show_axis()
	bridge_amt = 0
	for i in range(len(lines)):
		if (lines[i].check(ps[i][0], ps[i][1], ps[i][2], ps[i][3], 5) or lines[i].check(ps[i][2], ps[i][3], ps[i][0], ps[i][1], 5)):
			bridge_amt = bridge_amt + 1
			txt.src = "已经搭建完成" + str(bridge_amt) + "条星际廊桥"
		else:
			lines[i].x1 += random.randint(-1, 1)
			lines[i].y1 += random.randint(0, 2)
			lines[i].x2 += random.randint(-1, 1)
			lines[i].y2 += random.randint(0, 2)
	txt.draw()

def shape_q1():
	window.set_size(700, 800)
	bg = Rectangle(0, 0, 700, 800, "white")
	bg.draw()
	window.show_axis()
	lines = []

	lines.append(Line(100, 600, 200, 500, 2, "red"))
	lines.append(Line(300, 600, 400, 500, 6, "green"))
	lines.append(Line(500, 600, 600, 500, 10, "blue"))
	lines.append(Line(100, 400, 200, 300, 2, "green"))
	lines.append(Line(300, 400, 400, 300, 10, "blue"))
	lines.append(Line(500, 400, 600, 300, 6, "red"))
	lines.append(Line(100, 200, 200, 100, 6, "green"))
	lines.append(Line(300, 200, 400, 100, 10, "red"))

	lines.append(Line(150, 600, 150, 550, 6, "black"))
	lines.append(Line(350, 550, 400, 550, 6, "black"))
	lines.append(Line(550, 550, 550, 500, 6, "black"))
	lines.append(Line(150, 350, 100, 350, 6, "black"))
	lines.append(Line(350, 400, 350, 350, 6, "black"))
	lines.append(Line(550, 350, 600, 350, 6, "black"))
	lines.append(Line(150, 150, 150, 100, 6, "black"))
	lines.append(Line(350, 150, 300, 150, 6, "black"))

	lines.append(Rectangle(500, 100, 100, 100, "#EEEEEE"))
	lines.append(Text("?", 525, 120, 60, "white"))
	lines.append(Text("找规律，画出最后一个图形", 100, 700, 28, "black"))

	for l in lines:
		l.draw()

def shape_q2():
	window.set_size(700, 800)
	bg = Rectangle(0, 0, 700, 800, "white")
	bg.draw()
	window.show_axis()
	lines = []
	lines.append(Line(100, 600, 200, 600, 5, "blue"))
	lines.append(Line(100, 550, 200, 550, 10, "green"))
	lines.append(Line(100, 500, 200, 500, 15, "red"))
	lines.append(Line(300, 600, 300, 500, 5, "blue"))
	lines.append(Line(350, 600, 350, 500, 10, "green"))
	lines.append(Line(400, 600, 400, 500, 15, "red"))
	lines.append(Line(500, 600, 600, 600, 15, "red"))
	lines.append(Line(500, 550, 600, 550, 10, "green"))
	lines.append(Line(500, 500, 600, 500, 5, "blue"))

	lines.append(Line(100, 400, 100, 300, 5, "red"))
	lines.append(Line(150, 400, 150, 300, 10, "blue"))
	lines.append(Line(200, 400, 200, 300, 15, "green"))
	lines.append(Line(300, 400, 400, 400, 15, "green"))
	lines.append(Line(300, 350, 400, 350, 10, "blue"))
	lines.append(Line(300, 300, 400, 300, 5, "red"))
	lines.append(Line(500, 400, 500, 300, 15, "green"))
	lines.append(Line(550, 400, 550, 300, 10, "blue"))
	lines.append(Line(600, 400, 600, 300, 5, "red"))
	
	lines.append(Line(100, 200, 200, 200, 5, "green"))
	lines.append(Line(100, 150, 200, 150, 10, "red"))
	lines.append(Line(100, 100, 200, 100, 15, "blue"))
	lines.append(Line(300, 200, 300, 100, 5, "green"))
	lines.append(Line(350, 200, 350, 100, 10, "red"))
	lines.append(Line(400, 200, 400, 100, 15, "blue"))

	lines.append(Rectangle(500, 100, 100, 100, "#EEEEEE"))
	lines.append(Text("?", 525, 120, 60, "white"))
	lines.append(Text("找规律，画出最后一个图形", 100, 700, 28, "black"))

	for l in lines:
		l.draw()

def shape_q3():
	window.set_size(600, 700)
	bg = Rectangle(0, 0, 600, 700, "white")
	bg.draw()
	window.show_axis()
	lines = []
	lines.append(Text("用四条相连的线段连接所有圆点", 100, 550, 20, "black"))
	for i in range(0, 9):
		lines.append(Circle(200 + 100 * (i % 3), 200 + 100 * (i - i % 3) / 3, 10, "black"))
	for l in lines:
		l.draw()

def shape_q4():
	window.set_size(800, 800)
	bg = Rectangle(0, 0, 800, 800, "white")
	bg.draw()
	window.show_axis()
	lines = []
	t = Text("请画出四条线段，分别将下列图形分成面积相等的两部分", 100, 700, 15, "black")
	t.draw()
	lines.append(Circle(200, 200, 100))
	lines.append(Polygon(100, 600, 250, 600, 300, 400, 150, 400))
	lines.append(Triangle(450, 600, 700, 400, 400, 400))
	lines.append(Rectangle(400, 100, 300, 200))
	for l in lines:
		l.color = "blue"
		l.line_width = 3
		l.stroke()

# Lesson 3
def emoji1():
	window.set_size(400, 400)
	bg = Rectangle(0, 0, 400, 400, "white")
	bg.draw()
	face = Circle(200, 200, 150, "gray")
	face.stroke()
	mouth = Rectangle(150, 125, 100, 10, "gray")
	mouth.stroke()
	left_eye = Circle(150, 230, 15, "gray")
	left_eye.stroke()
	right_eye = Circle(250, 230, 15, "gray")
	right_eye.stroke()

def emoji2():
	window.set_size(400, 400)
	bg = Rectangle(0, 0, 400, 400, "white")
	bg.draw()
	face = Circle(200, 200, 150, "gray")
	face.stroke()
	mouth = Rectangle(170, 125, 60, 10, "gray")
	mouth.stroke()
	left_eyebrow = Line(160, 305, 105, 285, 10, "gray")
	left_eyebrow.stroke()
	left_eyebrow1 = Line(159, 304.6, 106, 285.3, 8, "white")
	left_eyebrow1.draw()
	right_eyebrow = Line(240, 305, 295, 285, 10, "gray")
	right_eyebrow.stroke()
	right_eyebrow1 = Line(241, 304.6, 294, 285.3, 8, "white")
	right_eyebrow1.draw()
	left_eye = Circle(140, 220, 40, "gray")
	left_eye.stroke()
	left_eye1 = Circle(140, 220, 10, "gray")
	left_eye1.stroke()
	right_eye = Circle(260, 220, 40, "gray")
	right_eye.stroke()
	right_eye1 = Circle(260, 220, 10, "gray")
	right_eye1.stroke()

def emoji3():
	window.set_size(400, 400)
	bg = Rectangle(0, 0, 400, 400, "white")
	bg.draw()
	face = Circle(200, 200, 150, "gray")
	face.stroke()
	mouth = Rectangle(170, 125, 60, 10, "gray")
	mouth.stroke()
	left_eyebrow = Line(160, 305, 105, 285, 10, "gray")
	left_eyebrow.stroke()
	left_eyebrow1 = Line(159, 304.6, 106, 285.3, 8, "white")
	left_eyebrow1.draw()
	right_eyebrow = Line(240, 305, 295, 285, 10, "gray")
	right_eyebrow.stroke()
	right_eyebrow1 = Line(241, 304.6, 294, 285.3, 8, "white")
	right_eyebrow1.draw()
	left_eye = Circle(140, 220, 40, "gray")
	left_eye.stroke()
	left_eye1 = Circle(140, 220, 10, "gray")
	left_eye1.stroke()
	right_eye = Circle(260, 220, 40, "gray")
	right_eye.stroke()
	right_eye1 = Circle(260, 220, 10, "gray")
	right_eye1.stroke()
	
def mars_rover1():
    window.set_size(800, 600)
    a = [];
    a.append(Rectangle(0, 0, 800, 600, "#FFF8DC"))
    n = Sprite("https://r.leaplearner.com/ud/production/A01T0008/vOmW.png", 400, 300)
    n.scale = 0.6
    a.append(n)
    a.append(Rectangle(458, 280, 24, 132, "black"))
    a.append(Rectangle(460, 280, 20, 130, "#DDDDDD"))
    a.append(Rectangle(298, 198, 204, 104, "black"))
    a.append(Rectangle(220, 305, 20, 20, "orange"))
    a.append(Rectangle(222, 325, 16, 70, "black"))
    a.append(Rectangle(224, 325, 12, 68, "red"))
    a.append(Rectangle(300, 200, 200, 100, "#DDDDDD"))
    a.append(Rectangle(198, 298, 304, 14, "black"))
    a.append(Rectangle(200, 300, 300, 10, "#DDDDDD"))
    a.append(Rectangle(428, 398, 84, 34, "black"))
    a.append(Rectangle(430, 400, 80, 30, "#DDDDDD"))
    a.append(Polygon(290, 340, 280, 310, 300, 310, "black"))
    a.append(Circle(290, 340, 10, "orange"))
    a.append(Polygon(268, 425, 275, 360, 310, 325, 375, 313, "#DDDDDD"))
    n = Ellipse(325, 370, 18, 78, "orange")
    n.set_anchor(325, 370)
    n.rotation = 45
    a.append(n)
    n = Ellipse(320, 370, 10, 55, "white")
    n.set_anchor(325, 370)
    n.rotation = 45
    a.append(n)
    n = Rectangle(310, 365, 15, 10, "black")
    n.set_anchor(325, 370)
    n.rotation = 45
    a.append(n)
    a.append(Line(500, 300, 550, 400, 20, "orange"))
    a.append(Line(550, 400, 665, 380, 20, "orange"))
    a.append(Polygon(660, 370, 680, 350, 730, 350, 730, 355, 685, 365, 675, 385, "black"))
    a.append(Polygon(690, 402, 730, 410, 729, 416, 680, 415, 655, 385, 675, 385, "black"))
    a.append(Circle(550, 400, 12, "black"))
    a.append(Circle(550, 400, 10, "white"))
    a.append(Circle(550, 400, 5, "black"))
    a.append(Circle(665, 380, 12, "black"))
    a.append(Circle(665, 380, 10, "white"))
    a.append(Circle(665, 380, 5, "black"))
    a.append(Circle(500, 300, 12, "black"))
    a.append(Circle(500, 300, 10, "white"))
    a.append(Circle(500, 300, 5, "black"))
    a.append(Circle(450, 425, 17, "black"))
    a.append(Circle(450, 425, 15, "orange"))
    a.append(Circle(450, 425, 12, "white"))
    a.append(Circle(490, 425, 17, "black"))
    a.append(Circle(490, 425, 15, "orange"))
    a.append(Circle(490, 425, 12, "white"))
    a.append(Circle(490, 425, 11, "blue"))
    a.append(Circle(150, 140, 50, "black"))
    a.append(Circle(150, 140, 40, "gray"))
    a.append(Circle(150, 140, 10, "orange"))
    a.append(Circle(390, 140, 50, "black"))
    a.append(Circle(390, 140, 40, "gray"))
    a.append(Circle(390, 140, 10, "orange"))
    a.append(Circle(660, 140, 50, "white"))
    a.append(Line(310, 280, 560, 280, 20, "orange"))
    a.append(Line(310, 280, 260, 210, 20, "orange"))
    a.append(Circle(310, 280, 10, "orange"))
    a.append(Line(200, 210, 340, 210, 20, "orange"))
    a.append(Line(200, 210, 150, 140, 20, "orange"))
    a.append(Line(340, 210, 390, 140, 20, "orange"))
    a.append(Circle(200, 210, 10, "orange"))
    a.append(Circle(340, 210, 10, "orange"))
    a.append(Circle(400, 280, 17, "black"))
    a.append(Circle(400, 280, 15, "white"))
    a.append(Circle(400, 280, 7, "black"))
    a.append(Circle(260, 210, 17, "white"))
    a.append(Circle(150, 140, 6, "black"))
    a.append(Circle(390, 140, 6, "black"))
    for shape in a:
        shape.draw()
        
def mars_rover2():  
    a = [];
    a.append(Line(560, 280, 660, 140, 20, "orange"))
    a.append(Circle(560, 280, 10, "orange"))
    a.append(Circle(660, 140, 10, "orange"))
    a.append(Circle(660, 140, 6, "black"))
    for shape in a:
        shape.draw()
    window.show_axis()

sate = Sprite("https://r.leaplearner.com/ud/production/A01T0008/bOGM.png", 300, 850)
sate.scale = 0.3
sate.set_anchor(300, 300)
angle = 0;
red_s = Sprite("https://r.leaplearner.com/ud/production/A01T0008/6kC3.png", 300, 300)
red_s.show = True
blue_s = Sprite("https://r.leaplearner.com/ud/production/A01T0008/X2ky.png", 300, 300)
blue_s.show = True
green_s = Sprite("https://r.leaplearner.com/ud/production/A01T0008/Rsi1.png", 300, 300)
green_s.show = True

def satellite():
    global angle
    window.set_size(600, 600)
    window.clear()
    bg = Sprite("https://r.leaplearner.com/ud/production/A01T0008/ezTx.jpg", 300, 300)
    bg.draw()
    window.show_axis()
    if (red_s.show):
        red_s.draw()
    if (blue_s.show):
        blue_s.draw()
    if (green_s.show):
        green_s.draw()
    angle -= 0.3

def launch(track):
    if (isinstance (track, Circle)):
        if (track.x == 300 and track.y == 300 and track.r > 160 and track.r < 180 and track.color == "red"):
            sate.x = 300
            sate.y = 850
            sate.rotation = angle
            sate.draw()
            red_s.show = False
        elif (track.x == 300 and track.y == 300 and track.r > 205 and track.r < 225 and track.color == "blue"):
            sate.x = 300
            sate.y = 1000
            sate.rotation = angle - 120
            sate.draw()
            blue_s.show = False
        elif (track.x == 300 and track.y == 300 and track.r > 246 and track.r < 266 and track.color == "green"):
            sate.x = 300
            sate.y = 1150
            sate.rotation = angle - 240
            sate.draw()
            green_s.show = False

# Lesson 4        
def solar():
    window.set_size(800, 500)
    window.clear()
    bg = Sprite("https://r.leaplearner.com/ud/production/A01T0008/heEu.jpg", 400, 250)
    bg.draw()
    window.show_axis()

#Lesson 5
e_icon = Sprite("https://r.leaplearner.com/i/Fighter7.png", 20, 20, 30, 30)
def on_fire(self):
    self.bullet = Sprite("https://r.leaplearner.com/ud/production/A01T0008/rfSi.png", self.x, self.y, 30, 55)
    self.bullet.speed = -3
    self.fire = True
def move_shoot(self):
    self.y += self.speed
    if (self.fire):
        self.bullet.y += self.bullet.speed
        self.bullet.draw()
        if (self.bullet.collide(hero)):
            self.bullet.scale_y = -1
            self.bullet.speed = 5 
        if (self.bullet.scale_y == -1 and self.bullet.collide(self)):
            enemies.remove(self)
        if (self.bullet.y < 0):
            hero.state = 2
    if (self.y < window.height and self.fire == False):
        self.on_fire()
    self.draw() 
    
Sprite.on_fire = on_fire
Sprite.move_shoot = move_shoot
bg = Sprite("https://r.leaplearner.com/i/circuitrybg1.png", 300, 300, 600, 600)
planet = Sprite("https://r.leaplearner.com/i/bg2.png", 300, -25, 600, 150)
hero = Sprite("https://r.leaplearner.com/ud/production/A01T0008/6mMS.png", 300, 100, 100, 90)
txt = Text("", 150, 300, 20, "white")
enemies = []
e_x = 0
e_y = window.height
hero.state = 0 # 0：游戏中 1：胜利 2：失败
for i in range(0, 20):
    e_x = random.randint(50, window.width - 50)
    e_y += random.randint(30, 150)
    new_enemy = Sprite("https://r.leaplearner.com/i/Fighter7.png", e_x, e_y, 100, 80)
    new_enemy.speed = -1
    new_enemy.fire = False
    enemies.append(new_enemy)
def win():
    window.clear()
    txt.src = "你成功地保卫了整个星球！"
    bg.draw()
    planet.draw()
    hero.draw()
    txt.draw()
def lose():
    window.clear()
    txt.src = "战斗失败，星球毁灭……"
    bg.draw()
    planet.draw()
    hero.draw()
    txt.draw()
def defend():
    global enemies
    window.clear()
    bg.draw()
    planet.draw()
    hero.draw()
    for enemy in enemies:
        enemy.move_shoot()
    if (len(enemies) <= 0):
        hero.state = 1
    else:
        for i in range(0, len(enemies)):
            e_icon.x = 20 + 40 * (i % 10)
            e_icon.y = window.height - 20 - (i - i % 10) / 10 * 40
            e_icon.draw()
def planet_defender():
    window.set_size(600, 600)
    if (hero.state == 0):
        defend()
    elif (hero.state == 1):
        win()
    elif (hero.state == 2):
        lose()

stones = []
signal = Sprite("https://r.leaplearner.com/ud/production/A01T0008/qpDU.png", random.randint(0, 560), 540, 40, 40)
signal.ys = random.uniform(0.5, 2.5)
decode_rect = Rectangle()
rect = Rectangle(10, 450, 50, 40, "red")
game_txt = Text("截获情报", 220, 460, 15, "white")
frame = Sprite("https://r.leaplearner.com/ud/production/A01T0008/3Puv.png", 300, 250, 500, 380)
boss = Sprite("https://r.leaplearner.com/i/Fighter11.png", 172, 250, 150, 100)
boss_txt = Text("首领：小丑战机", 90, 155)
boss_intro = Text("", font_size = 10, color = "white")
decode_txt = Text("情报分析中……", 230, 275, 15, "white")
fail_txt = Text("你被陨石击中，按下空格键重启机器人", 110, 240, 15, "white")
def information():
	hero.x = 300
	hero.y = 250
	hero.w = 50
	hero.h = 50
	hero.state = "alive"
	hero.score = 0
	hero.decoding = 0
	
def add_stone():
    stone = Sprite("https://r.leaplearner.com/ud/production/A01T0008/lD1S.png")
    stone.w = 30
    stone.h = 30
    stone.xs = random.uniform(0.5, 2.5) * random.randrange(-1, 2, 2)
    stone.ys = random.uniform(0.5, 2.5) * random.randrange(-1, 2, 2)
    stone.x = random.uniform(0, 200) + random.randint(0, 1) * 700
    stone.y = random.uniform(0, 200) + random.randint(0, 1) * 800
    stones.append(stone)
for i in range(0, 6):
    add_stone()
def reconnoitre():
    global stones
    window.set_size(600, 500)
    window.clear()
    bg.draw()
    if (hero.state == "alive"):
        signal.y -= signal.ys
        if (signal.y < 0):
            signal.y = 540
            signal.x = random.randint(0, 560)
        if (signal.collide(hero)):
            signal.y = 540
            signal.x = random.randint(0, 560)
            hero.score += 1
        signal.draw()
        hero.draw()
        for s in stones:
            s.x += s.xs
            s.y += s.ys
            if (s.x < 0):
                s.xs = random.uniform(0.5, 2.5)
            if (s.x > 570):
                s.xs = -random.uniform(0.5, 2.5)
            if (s.y < 0):
                s.ys = random.uniform(0.5, 2.5)
            if (s.y > 470):
                s.ys = -random.uniform(0.5, 2.5)
            s.draw()
            if (s.collide(hero)):
                hero.state = "dead"
        rect.color = "red"
        rect.w = hero.score * 58
        rect.draw()
        rect.w = 580
        rect.line_width = 2
        rect.color = "white"
        rect.stroke()
        game_txt.src = "情报截获：" + str(hero.score * 10) + "%"
        game_txt.draw()
        if (hero.score >= 10):
            hero.state = "decode"
    elif (hero.state == "dead"):
        fail_txt.draw()
    elif (hero.state == "win"):
        frame.draw()
        boss.draw()
        boss_txt.color = "white"
        boss_txt.draw()
        boss_intro.src = "来自哈哈星球的杀手型飞船"
        boss_intro.x = 280
        boss_intro.y = 290
        boss_intro.draw()
        boss_intro.src = "嗜血、冷酷、毫不留情"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "它具有强大的武器和超强的防御"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "机头和两翼配备了三个护盾生成系统"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "当其中一个受到攻击时"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "其余两个可以实现联动防护"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "因此，必须同时攻击它的机头和双翼"
        boss_intro.y -= 20
        boss_intro.draw()
        boss_intro.src = "才能对它造成真正的伤害"
        boss_intro.y -= 20
        boss_intro.draw()
    elif (hero.state == "decode"):
        hero.decoding += 1
        decode_rect.x = 100
        decode_rect.y = 235
        decode_rect.w = hero.decoding
        decode_rect.h = 30
        decode_rect.color = "red"
        decode_rect.draw()
        decode_rect.w = 400
        decode_rect.color = "white"
        decode_rect.stroke()
        decode_txt.draw()
        if (hero.decoding >= 400):
            hero.state = "win"

def go_left():
    hero.x -= 30
def go_right():
    hero.x += 30
def go_up():
    hero.y += 30
def go_down():
    hero.y -= 30
def restart():
    global stones
    if (hero.state == "dead"):
        signal.y = 540
        signal.x = random.randint(0, 560)
        for s in stones:
            s.xs = random.uniform(0.5, 2.5) * random.randrange(-1, 2, 2)
            s.ys = random.uniform(0.5, 2.5) * random.randrange(-1, 2, 2)
            s.x = random.uniform(0, 200) + random.randint(0, 1) * 700
            s.y = random.uniform(0, 200) + random.randint(0, 1) * 800
        hero.x = 300
        hero.y = 250
        hero.score = 0
        hero.decoding = 0
        hero.state = "alive"


from pyleap import *
#from garden import *
import random

#云
def draw_cloud(cloud_number=0):
    #从左到右
    if cloud_number == 1:
        #云朵1
        Ellipse(90, 70, 60, 28, 'white').draw()
        Ellipse(43, 67, 50, 20, 'white').draw()
        Ellipse(150, 70, 30, 20, 'white').draw()    
    elif cloud_number == 2:
        #云朵1
        Ellipse(90, 70, 60, 28, 'white').draw()
        Ellipse(43, 67, 50, 20, 'white').draw()
        Ellipse(150, 70, 30, 20, 'white').draw()
        #云朵2
        Ellipse(320, 50, 60, 28, 'white').draw()
        Ellipse(370, 50, 30, 20, 'white').draw()
    elif cloud_number == 3:
        #云朵1
        Ellipse(90, 70, 60, 28, 'white').draw()
        Ellipse(43, 67, 50, 20, 'white').draw()
        Ellipse(150, 70, 30, 20, 'white').draw()
        #云朵2
        Ellipse(320, 50, 60, 28, 'white').draw()
        Ellipse(370, 50, 30, 20, 'white').draw()
        #云朵3
        Ellipse(490, 110, 60, 28, 'white').draw()
        Ellipse(545, 100, 50, 20, 'white').draw()
    elif cloud_number == 4:
        #云朵1
        Ellipse(90, 70, 60, 28, 'white').draw()
        Ellipse(43, 67, 50, 20, 'white').draw()
        Ellipse(150, 70, 30, 20, 'white').draw()
        #云朵2
        Ellipse(320, 50, 60, 28, 'white').draw()
        Ellipse(370, 50, 30, 20, 'white').draw()
        #云朵3
        Ellipse(490, 110, 60, 28, 'white').draw()
        Ellipse(545, 100, 50, 20, 'white').draw()
        #云朵4
        Ellipse(500, 40, 60, 20, 'white').draw()
def draw_flower(flower_number=0):
    if flower_number == 1:
        flower1 = Sprite("https://r.leaplearner.com/ud/production/615020/uIcq.png", 50, 170)
        flower1.scale = 0.2
        flower1.draw()
    elif flower_number == 2:
        flower1 = Sprite("https://r.leaplearner.com/ud/production/615020/uIcq.png", 50, 170)
        flower2 = Sprite("https://r.leaplearner.com/ud/production/615020/s4P3.png", 80, 200)
        flower1.scale = 0.2
        flower2.scale = 0.2
        flower1.draw()
        flower2.draw()
    elif flower_number == 3:
        flower1 = Sprite("https://r.leaplearner.com/ud/production/615020/uIcq.png", 50, 170)
        flower2 = Sprite("https://r.leaplearner.com/ud/production/615020/s4P3.png", 80, 200)
        flower3 = Sprite("https://r.leaplearner.com/ud/production/615020/RBTJ.png", 110, 220)
        flower1.scale = 0.2
        flower2.scale = 0.2
        flower3.scale = 0.2
        flower1.draw()
        flower2.draw()
        flower3.draw()
    elif flower_number == 4:
        flower1 = Sprite("https://r.leaplearner.com/ud/production/615020/uIcq.png", 50, 170)
        flower2 = Sprite("https://r.leaplearner.com/ud/production/615020/s4P3.png", 80, 200)
        flower3 = Sprite("https://r.leaplearner.com/ud/production/615020/RBTJ.png", 110, 220)
        flower4 = Sprite("https://r.leaplearner.com/ud/production/615020/HeqZ.png", 160, 280)
        flower1.scale = 0.2
        flower2.scale = 0.2
        flower3.scale = 0.2
        flower4.scale = 0.2
        flower1.draw()
        flower2.draw()
        flower3.draw()
        flower4.draw()
#树n
t1 = Ellipse(345, 300, 20, 30, "black")
t2 = Ellipse(380, 290, 15, 35, "black")
t3 = Ellipse(400, 320, 20, 40, "black")
t4 = Ellipse(385, 150, 20, 30, "black")
t5 = Ellipse(435, 170, 20, 40, "black")
t6 = Ellipse(500, 280, 20, 40, "black")
t7 = Ellipse(530, 320, 20, 40, "black")
t8 = Ellipse(555, 250, 20, 40, "black")
t9 = Ellipse(590, 275, 15, 30, "black")
t10 = Ellipse(610, 320, 15, 45, "black")
#飞机
plane = Sprite("https://r.leaplearner.com/ud/production/615020/zes9.png", 500, 400)
#鱼
fish1 = Sprite("https://r.leaplearner.com/ud/production/615020/FnX7.png", 156, 127)
fish2 = Sprite("https://r.leaplearner.com/ud/production/615020/jeu6.png", 16, 129)
fish3 = Sprite("https://r.leaplearner.com/ud/production/615020/Gd98.png", 160, 156)
#天空
skys = Rectangle(0, 0, 650, 500, "blue")
#太阳和月亮
suns = Circle(100, 420, 50, "orange")
def draw_all(dt):
    window.set_size(650, 500)
    #背景天空
    skys.draw()
    
    #太阳    
    suns.draw()

    #空中花园基地
    Ellipse(325, 200, 500, 100, '#CCCC33').draw()

    #河流
    river = '#66CCFF'
    Rectangle(0, 0, 32, 148, river).draw()
    Rectangle(32, 116, 150, 32, river).draw()
    Rectangle(130, 136, 400, 32, river).draw()
    if showfish == True:
        #鱼
        fish2.scale = 0.09
        fish1.scale = 0.08
        fish3.scale = 0.08
        fish1.draw()
        fish2.draw()
        fish3.draw() 
 
    #山丘
    Triangle(460, 300, 360, 170, 650, 170, '#CCCC99').draw()
    Triangle(450, 105, 580, 255, 700, 120, '#9999CC').draw()
    #亭子
    Triangle(370, 250, 340, 220, 400, 220, '#996633').draw()
    Rectangle(345, 185, 5, 35, '#663300').draw()
    Rectangle(390, 185, 5, 35, '#663300').draw()
    Line(340,185,400,185,3,'#333333').draw()

    #大树
    #左上三棵树
    #树1
    t1.draw()
    Line(345, 290, 345, 250, 2, '#663300').draw()
    #树2
    t2.draw()
    Line(380, 290, 380, 245, 2, '#663300').draw()
    #树3
    t3.draw()
    Line(400, 320, 400, 260, 2, '#663300').draw()

    #左下两棵
    #树4
    t4.draw()
    Line(385, 150, 385, 100, 2, '#663300').draw()
    #树5
    t5.draw()
    Line(435, 170, 435, 100, 2, '#663300').draw()
    
    #右上五棵树
    #树6
    t6.draw()
    Line(500, 280, 500, 230, 2, '#663300').draw()
    #树7
    t7.draw()
    Line(530, 320, 530, 270, 2, '#663300').draw()
    #树8
    t8.draw()
    Line(555, 250, 555, 205, 2, '#663300').draw()
    #树9
    t9.draw()
    Line(590, 275, 590, 234, 2, '#663300').draw()
    #树10
    t10.draw()
    Line(610, 260, 610, 320,  2, '#663300').draw()
               
    #云
    draw_cloud(cloud_number)

    #花
    draw_flower(flower_number)
    
    #飞机
    plane.scale = 0.5
    plane.draw()
def s(start=1, flower=0, cloud=0, tree1="black", tree2="black", tree3="black", tree4="black", tree5="black", tree6="black",
      tree7="black", tree8="black", tree9="black", tree10="black", speed=0, speed1=0, speed2=0, speed3=0, sun="orange", sky="blue"):
    global showfish
    if start == 1:
        showfish = False
        global flower_number,cloud_number
        flower_number = flower
        cloud_number = cloud
        t1.color = tree1
        t2.color = tree2
        t3.color = tree3
        t4.color = tree4
        t5.color = tree5
        t6.color = tree6
        t7.color = tree7
        t8.color = tree8
        t9.color = tree9
        t10.color = tree10    
        speed = speed
        def fly(dt):
            plane.x -= speed
        repeat(draw_all)
        repeat(fly)    
        run()
    elif start == 2:
        showfish = True
        flower_number = flower
        cloud_number = cloud
        t1.color = tree1
        t2.color = tree2
        t3.color = tree3
        t4.color = tree4
        t5.color = tree5
        t6.color = tree6
        t7.color = tree7
        t8.color = tree8
        t9.color = tree9
        t10.color = tree10
        speed = speed
        speed1 = speed1
        speed2 = speed2
        speed3 = speed3
        def swiming(dt):
            fish1.x -= speed1
            fish2.y -= speed2
            fish3.x += speed3
        def fly(dt):
            plane.x -= speed
        repeat(draw_all)
        repeat(fly)
        repeat(swiming)
        run()
    elif start == 3:
        showfish = True
        flower_number = flower
        cloud_number = cloud
        t1.color = tree1
        t2.color = tree2
        t3.color = tree3
        t4.color = tree4
        t5.color = tree5
        t6.color = tree6
        t7.color = tree7
        t8.color = tree8
        t9.color = tree9
        t10.color = tree10
        skys.color = sky
        suns.color = sun
        speed = speed
        speed1 = speed1
        speed2 = speed2
        speed3 = speed3
        def swiming(dt):
            fish1.x -= speed1
            fish2.y -= speed2
            fish3.x += speed3
        def fly(dt):
            plane.x -= speed
        repeat(draw_all)
        repeat(fly)
        repeat(swiming)
        run()



from pyleap import *
window.set_size(500, 500)
a1 = Circle(125,250,25,'white')
a2 = Circle(105,250,20,'white')
a3 = Circle(140,250,20,'white')
a4 = Circle(160,250,10,'white')



c1 = Circle(375,300,25,'white')
c2 = Circle(360,300,20,'white')
c3 = Circle(390,300,20,'white')
c4 = Circle(410,300,10,'white')

#太阳
sun = Circle(410,430,40,'yellow')


def draw1():
    
    #背景
    Rectangle(0, 0, 500, 500, "cyan").draw()
    
    #太阳
    sun.draw()
    
    #云朵
    a1.draw()
    a2.draw()
    a3.draw()
    a4.draw()


    c1.draw()
    c2.draw()
    c3.draw()
    c4.draw()
    window.show_axis()




from pyleap import *

window.set_size(900,600)
# 创建对象
bg = Sprite("https://r.leaplearner.com/ud/production/207155/ZoWs.jpg", 450,400)
bg.scale = 1.8
def star(x,y):
    star = Sprite("https://r.leaplearner.com/ud/production/615020/4dks.png",x,y)
    star.scale = 0.15
    star.draw()
def star2(x, y):
    star2 = Sprite("https://r.leaplearner.com/ud/production/615020/NeHP.png",x,y)
    star2.scale = 0.15
    star2.draw()
def draw1():    
    bg.draw()
    window.show_axis()




from pyleap import *
import random
import time
import math


#设置游戏区域大小
window.set_size(600, 600)

window.set_caption("雷霆战机")

enemy = Sprite('https://r.leaplearner.com/i/7686bf.png')
rock = Sprite('https://r.leaplearner.com/i/4a165e.png')

#保护罩
defend = Sprite('https://r.leaplearner.com/i/24dc6b.png')
speck = Sprite('https://r.leaplearner.com/ud/production/958096/5Mex.png',640,random.randint(0, 600))
defend.scale = 2

#设置背景图片、player图片和爆炸效果
background = Sprite("https://r.leaplearner.com/ud/production/958096/koZU.png",350,475)
background1 = Sprite("https://r.leaplearner.com/ud/production/958096/CTRe.png",350,1436)
background.h = 643
background.w = 501
background1.h = 642
background1.w = 501
player = Sprite("https://r.leaplearner.com/ud/production/958096/QKiT.png")
#改变敌人和战机大小
player.scale = 0.6
enemy.scale = 0.3
#闪屏
shan = Sprite('https://r.leaplearner.com/ud/production/958096/M44i.png')
shan.scale = 1

#保护罩大小
#defend.scale = 0.5

background.scale = 1.5
background1.scale = 1.5

boomscale = 0.3            
playerscale = 0.5          
boom = Sprite("https://r.leaplearner.com/i/0c4952.png")
#改变爆炸大小
boom.scale = 0.5

boom_rock = Sprite('https://r.leaplearner.com/i/0c4952.png')
boom_rock.scale = 0.5

#设置敌人总部
player.bullets = []
enemys = []
temp_enemys = []
rock_rocks = []  #陨石


#设置得分
player.score = 0
score_txt = Text("得分：", 10, 540)


#游戏结束标语
retry_txt = Text("GAME OVER!!!", 200, 400, font_size=30)


#设置游戏时间
start_time = time.time()
time_txt = Text("剩余时间：" + str(math.floor(30 - (time.time() - start_time))), 10, 560)
global game_over
game_over = False

#子弹工厂
def emit_bullet(dt):
    bullet = Sprite('https://r.leaplearner.com/ud/production/958096/kUnZ.png', player.x, player.y)
    bullet.scale = 0.5
    player.bullets.append(bullet)


#敌机工厂
def new_enemy(dt):
    enemy1 = Sprite(enemy.src, random.randint(0, 600), 600)   #3\4   5\6
    enemy1.scale = enemy.scale
    enemy1.speed = random.randint(3,5)
    enemys.append(enemy1)

#陨石工厂
def emit_rock(dt):
    a = random.randint(1,4)
    rock1 = Sprite('https://r.leaplearner.com/ud/production/958096/8Upk.png',0, random.randint(400, 600))
    rock1_1 = Sprite('https://r.leaplearner.com/ud/production/958096/8Upk.png',random.randint(100, 400), 600)
    rock2 = Sprite('https://r.leaplearner.com/ud/production/958096/6zSV.png',0, random.randint(500, 600))
    rock2_2 = Sprite('https://r.leaplearner.com/ud/production/958096/6zSV.png',random.randint(100, 400), 600)
    rock1.scale = random.randint(2,3) / 10
    rock1_1.scale = random.randint(2,3) / 10
    rock2.scale = random.randint(2,3) / 10
    rock2_2.scale = random.randint(2,3) / 10
    rock1.xs = random.randint(2,2)
    rock1.ys = random.randint(-5,-3)
    rock1_1.xs = random.randint(2,2)
    rock1_1.ys = random.randint(-5,-3)
    rock2.xs = random.randint(2,2)
    rock2.ys = random.randint(-5,-3)
    rock2_2.xs = random.randint(2,2)
    rock2_2.ys = random.randint(-5,-3)
    if a == 1:
        rock_rocks.append(rock1)
    elif a == 2:
        rock_rocks.append(rock1_1)
    elif a == 3:
        rock_rocks.append(rock2)
    elif a == 4:
        rock_rocks.append(rock2_2)


#在窗口中绘制角色
def draw():
    #window.clear()
    #background.draw()
    #background1.draw()
    
    for enemy in enemys:
        enemy.draw()
        
    for bullet in player.bullets:
        bullet.draw()

    for rock in rock_rocks:
        rock.draw()

    player.draw()

    #开局5秒保护罩、之后消失、获取。
    if math.floor(time.time() - start_time) <= 5:
       defend.x = player.x
       defend.y = player.y
       defend.draw()
    elif math.floor(time.time() - start_time) > 5:
        if speck.collide(player):
            speck.y = 2500
        else:
            #speck.scale = 0.5
            speck.y -= 5
            speck.draw()
            if speck.y < -40:
                speck.y = 640
                speck.x = random.randint(0, 600)
                
        if speck.y > 1100:
            #defend.scale = player.scale * 0.85
            defend.x = player.x
            defend.y = player.y
            defend.draw()
        else:
            defend.y = -500
            defend.draw()

       
    score_txt.draw()
    time_txt.draw()


#让窗口中的角色运动
def update():
    global timer
    #控制player 跟随 mouse
    player.x =  mouse.x
    player.y =  mouse.y
    for enemy in enemys:
        enemy.y -= enemy.speed

    for bullet in player.bullets:
        bullet.y += 10

    for rock in rock_rocks:
        rock.y += rock.ys
        rock.x += rock.xs
            
    score_txt.src = "得分：" + str(player.score)
    time_txt.src = "剩余时间：" + str(math.floor(30 - (time.time() - start_time)))

#背景函数
def bg_run():
    window.clear()
    #防护罩实现，跟随飞机改变大小
    
    
    background.y -= 1
    background1.y -= 1
    if background.y < -475:
        background.y = 1436
    if background1.y < -475:
        background1.y = 1436
    background.draw()
    background1.draw()

    
#计算得分，删除敌机与子弹
def enemy_is_hit():
    try:
        #击中敌机
        for enemy in enemys:
            for bullet in player.bullets:
                p = bullet.collide(enemy) #子弹击中敌机
                p1 = defend.collide(enemy) #保护罩击中敌机
                if p1:
                    enemys.remove(enemy)
                    return True
                elif p:
                    enemys.remove(enemy)
                    player.bullets.remove(bullet)
                    return True
        #击中陨石
        for rock in rock_rocks:
            for bullet in player.bullets:
                p = bullet.collide(rock) #子弹击中敌机
                p1 = defend.collide(rock) #保护罩击中敌机
                if p1:
                    rock_rocks.remove(rock)
                    return True
                elif p:
                    rock_rocks.remove(rock)
                    player.bullets.remove(bullet)
                    return True
        
        return  False
    except:
        pass



#游戏引擎(发动机)1
def enemy_is_hit_a():
    try:
        #击中敌机特效
        for enemy in enemys:
            for bullet in player.bullets:
                p = bullet.collide(enemy) #子弹击中敌机
                p1 = defend.collide(enemy) #保护罩击中敌机
                if p1:
                    boom.x = p1.x
                    boom.y = p1.y
                    boom.draw()
                elif p:
                    boom.x = p.x
                    boom.y = p.y
                    boom.draw()
        #子弹优化
        for bullet in player.bullets:
            if bullet.y > window.h:
                player.bullets.remove(bullet)
        #敌机优化
        for enemy in enemys:
            if enemy.y < 0:
                enemys.remove(enemy)
        #击中陨石特效
        for rock in rock_rocks:
             for bullet in player.bullets:
                 p = bullet.collide(rock) #子弹击中敌机
                 p1 = defend.collide(rock) #保护罩击中敌机
                 p2 = player.collide(rock) #飞机撞击陨石
                 if p1:
                     boom_rock.x = p1.x
                     boom_rock.y = p1.y
                     boom_rock.draw()
                 elif p:
                     boom_rock.x = p.x
                     boom_rock.y = p.y
                     boom_rock.draw()
                 elif p2:
                     boom_rock.x = p2.x
                     boom_rock.y = p2.y
                     boom_rock.draw()
                     shan.draw()
        #陨石优化
        for rock in rock_rocks:
            if rock.y < 0:
                rock_rocks.remove(rock)
        for rock in rock_rocks:
            if rock.x > 600:
                rock_rocks.remove(rock)

    except:
        pass

def logic():
    global game_over
    
    #判断时间是否小于1，进行游戏结束,保护罩除外。
    for enemy in enemys:
        if defend.collide(enemy):
            pass
        elif player.collide(enemy):
            game_over = True
        if math.floor(30 - (time.time() - start_time)) < 0:
            game_over = True
    #判断是否碰到陨石，扣分
    for rock in rock_rocks:       
        if player.collide(rock):
            rock_rocks.remove(rock)
            player.score -= 2


#游戏引擎（发动机）2            
def game(dt):
    global game_over
    if(game_over):
        retry_txt.draw()
    else:
        bg_run()
        draw()
        enemy_is_hit_a()
        update()
        logic()
        if enemy_is_hit():    
            player.score += 2

#设置陨石出现频率
repeat(emit_rock,0.8)
#运行游戏

@window.event
def on_draw():
    game(1)

#retry_txt.on_press(retry)
#run()



# -*- coding: utf-8 -*-
from base64 import b64encode
from pprint import pprint
import requests
from pyleap import *

class FaceAI:
    pass
faceAI = FaceAI()


ty = Text("",860,550,20,"red",font_name="STHupo")
window.set_size(1000,600)
Open = Sprite("https://rss.leaplearner.com/ud/production//19671/158520767187985.png",880,50,200,70)
bg = Sprite("https://rss.leaplearner.com/teachfiles/Media/158580755490250.png",350,300,700,610)
faceAI.a=0
faceAI.state = 1
faceAI.m =1
error = Text("",130,250,30,"red",font_name="STHupo")
faceAI.photo = ["1.jpg"]
pic = Sprite(faceAI.photo[faceAI.a],350,300)


def judge():
    global Result,face,Emotion,gender,Mask
    if faceAI.m == 1:
        url = "https://aip.baidubce.com/rest/2.0/face/v3/detect"#接口地址
        headers = {"content-type":"application/json"}#固定参数
        p = open(faceAI.photo[faceAI.a],"rb")#用二进制的方式打开图片并保存到变量p中,注意后缀名
        image = str(b64encode(p.read()),"utf-8")#加密图片p并转换成字符格式保存到变量image中
        params = '{"image":"'+image+'","image_type":"BASE64","face_field":"faceshape,facetype,age,beauty,emotion,expression,gender,landmark,mask"}'
        ##验证信息，必要参数，获取方式见access_token项目
        host = 'https://aip.baidubce.com/oauth/2.0/token?grant_type=client_credentials&client_id=uEaxmSYYxuZNU0pa84TofGUE&client_secret=OWGZ8ffTySgDLhtbW2ZAUKbKUs1bwt0f'
        response = requests.get(host)
        access_token=response.json()['access_token']
        request_url = url +"?access_token="+access_token  #连接地址和验证信息
        #填写所有信息发送给百度，获取识别结果保存到变量response中
        response = requests.post(request_url,data = params,headers = headers)  
        response=response.json()
        R = response['result']
        faceAI.m = -1
        if R != None:
            faceAI.state = 1
            Result = response['result']['face_list'][0]
            faceAI.Result = Result
            pprint(Result)
            error.src = ""
            score = int(Result['beauty'])
            face = response['result']['face_list'][0]['face_type']['type']
            if face=="cartoon":
                ty.src = "卡通"
            else:
                ty.src = ""
        else:
            faceAI.state = 0
            error.src = "检测不到人脸,重新上传"   
    window.clear()
    Rectangle(0, 0, window.w, window.h, "white").draw()
    pic.src = faceAI.photo[faceAI.a]
    pic.draw()
    bg.draw()
    if faceAI.state == 1:
        c = []
        for j in range(72):
            x = Result['landmark72'][j]['x']
            y = Result['landmark72'][j]['y']
            c.append(Circle(int(x)+350-0.5*pic.w,300+0.5*pic.h-int(y),1,"red"))     
        for j in range(72):
            c[j].draw()
    Open.draw()
    if faceAI.a == len(faceAI.photo)-1:
        Text("这是最后一张图片",100,60,20,"red",font_name="STHupo").draw()
    error.draw()

    
def Next():
    faceAI.m = 1
    faceAI.state = 1
    if faceAI.a < len(faceAI.photo)-1:
        faceAI.a += 1
    pic.src = faceAI.photo[faceAI.a]
Open.on_press(Next)




from pyleap import *
window.set_size(500, 500)
def logo():
    #定义字体
    Text('School Bus',290,225,20,'white').draw()
    #定义车身上的线
    Line(295, 260, 425, 260, 3, 'black').draw()
    Line(295, 250, 425, 250, 3, 'black').draw()
    window.show_axis()
#背景
def bg():
    Rectangle(0, 0, 500, 500, 'cyan').draw()




import setuptools

# window: rmdir /s/q dist
# -$ python setup.py sdist bdist_wheel
# -$ twine upload dist/* -u VicWang -p PYPI******

setuptools.setup(
    name="leaptask",
    version="2021.12.18",
    author="Vic Wang",
    author_email="305880887@qq.com",
    description='leap task',
    long_description="leap tasks",
    long_description_content_type="text/markdown",
    url='http://github.com/XRDX/pyleap',
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ),
)



from pyleap import *
import random
import time
import math


#设置游戏区域大小
window.set_size(600, 600)

window.set_caption("雷霆战机")

enemy = Sprite('https://r.leaplearner.com/i/7686bf.png')
enemy1 = Sprite('https://r.leaplearner.com/i/758e85.png')
enemy2 = Sprite('https://r.leaplearner.com/i/00fb03.png')
enemy3 = Sprite('https://r.leaplearner.com/i/0786ea.png')
enemy2.src = "https://r.leaplearner.com/ud/production/958096/MBPg.jpg"
enemy3.src = "https://r.leaplearner.com/ud/production/958096/VXdc.png"

rock = Sprite('https://r.leaplearner.com/i/4a165e.png')
rock.scale = 100


#背景初定
background = Sprite("https://r.leaplearner.com/i/43204d.png")
background1 = Sprite("https://r.leaplearner.com/i/43204d.png",300,300)
background2 = Sprite("https://r.leaplearner.com/i/43204d.png",300,900)
background1.rotation = 180

#保护罩
defend = Sprite('https://r.leaplearner.com/i/1aec98.png')
speck = Sprite('https://r.leaplearner.com/i/89f3be.png',640,random.randint(0, 600))
defend.scale = 0.4
speck.scale = 1

#子弹
bullet = Sprite('https://r.leaplearner.com/i/a41556.png')
bullet.scale = 0.4

#设置背景分解
def update_bg(dt):
    background1.src = background.src
    background2.src = background.src


player = Sprite("https://r.leaplearner.com/i/882265.png")
#改变敌人和战机大小
player.scale = 0.2
enemy1.scale = 0.4
enemy2.scale = 0.3
enemy3.scale = 0.5

#闪屏
shan = Sprite('https://r.leaplearner.com/ud/production/958096/M44i.png')
shan.scale = 1


boomscale = 0.3            
playerscale = 0.5
boom = Sprite("https://r.leaplearner.com/ud/production/958096/TLRC.png")
boom1 = Sprite("https://r.leaplearner.com/ud/production/958096/TLRC.png")
boom2 = Sprite("https://r.leaplearner.com/ud/production/958096/gyhU.png")

#改变爆炸大小
boom.scale = 0.04
boom_rock = Sprite('https://r.leaplearner.com/ud/production/958096/6mSw.png')
boom_rock.scale = 0.5

#设置敌人总部
player.bullets = []
enemys = []
temp_enemys = []
rock_rocks = []  #陨石
boom_list = []
boom_rocks = []


#设置得分
player.score = 0
score_txt = Text("蛋糕数量：", 10, 540,color = "aquamarine")# sae aqua

#游戏结束标语
def retry():
    retry_txt = Text("GAME OVER!!!", 170, 300,font_size=30,color="red")
    retry_txt.draw()


#设置游戏时间
start_time = time.time()
time_txt = Text("剩余时间：" + str(math.floor(30 - (time.time() - start_time))), 10, 560,color = "aquamarine")#
global game_over
game_over = False

#时间初定
time_one = 30

bl = 0

#子弹工厂
def emit_bullet(dt):
    bullet1 = Sprite(bullet.src, player.x, player.y)
    bullet1.scale = bullet.scale
    bullet1.speed = 3
    player.bullets.append(bullet1)


#敌机工厂
def new_enemy(dt):
    enemy_a = Sprite(enemy1.src, random.randint(0, 600), 600)
    enemy_a.scale = enemy1.scale
    enemy_a.speed = random.randint(3,5)
    enemys.append(enemy_a)

    if enemy2.src != "https://r.leaplearner.com/ud/production/958096/MBPg.jpg":    
        enemy_a = Sprite(enemy2.src, random.randint(0, 600), 800)
        enemy_a.scale = enemy2.scale
        enemy_a.speed = random.randint(3,5) 
        enemys.append(enemy_a)

    if enemy3.src != "https://r.leaplearner.com/ud/production/958096/VXdc.png":    
        enemy_a = Sprite(enemy3.src, random.randint(0, 600), 650)
        enemy_a.scale = enemy3.scale
        enemy_a.speed = random.randint(3,5) 
        enemys.append(enemy_a)

#陨石工厂
def emit_rock(dt):
    a = random.randint(1,4)
    rock1 = Sprite(rock.src,0, random.randint(400, 600))
    rock1_1 = Sprite(rock.src,random.randint(100, 400), 600)
    rock2 = Sprite(rock.src,0, random.randint(500, 600))
    rock2_2 = Sprite(rock.src,random.randint(100, 400), 600)
    if rock.scale != 100:
        rock1.scale = rock.scale 
        rock1_1.scale = rock.scale 
        rock2.scale = rock.scale 
        rock2_2.scale = rock.scale
    else:
        rock1.scale = random.randint(40,70) / 100
        rock1_1.scale = random.randint(40,70) / 100
        rock2.scale = random.randint(40,70) / 100
        rock2_2.scale = random.randint(40,70) / 100
    rock1.xs = random.randint(2,2)
    rock1.ys = random.randint(-5,-3)
    rock1_1.xs = random.randint(2,2)
    rock1_1.ys = random.randint(-5,-3)
    rock2.xs = random.randint(2,2)
    rock2.ys = random.randint(-5,-3)
    rock2_2.xs = random.randint(2,2)
    rock2_2.ys = random.randint(-5,-3)
    if a == 1:
        rock_rocks.append(rock1)
    elif a == 2:
        rock_rocks.append(rock1_1)
    elif a == 3:
        rock_rocks.append(rock2)
    elif a == 4:
        rock_rocks.append(rock2_2)   

#在窗口中绘制角色
def draw():
    window.clear()
    bg_run()
    
    for enemy in enemys:
        enemy.draw()
        if enemy.y < -100:
            denemys.remove(enemy)
        
    for bullet in player.bullets:
        bullet.draw()
        if bullet.y > 700:
            del player.bullets[0]

    for rock in rock_rocks:
        rock.draw()
        if rock.x > 700:
            del rock_rocks[0]
        if rock.y < -100:
            del rock_rocks[0]

    for booms in boom_list:
        booms.draw()
    
    for rocks in boom_rocks:
        rocks.draw()
    
    player.draw()

    #开局5秒保护罩、之后消失、获取。
    if math.floor(time.time() - start_time) <= 5:
       defend.x = player.x
       defend.y = player.y
       defend.draw()
    elif math.floor(time.time() - start_time) > 5:
        if speck.collide(player):
            speck.y = 2500
        else:
            #speck.scale = 0.5
            speck.y -= 5
            speck.draw()
            if speck.y < -40:
                speck.y = 640
                speck.x = random.randint(0, 600)
                
        if speck.y > 1100:
            #defend.scale = player.scale * 0.85
            defend.x = player.x
            defend.y = player.y
            defend.draw()
        else:
            defend.y = -500
            defend.draw()
       
    score_txt.draw()
    time_txt.draw()


#让窗口中的角色运动
def update():
    global timer,time
    #控制player 跟随 mouse
    player.x =  mouse.x
    player.y =  mouse.y
    for enemy in enemys:
        enemy.y -= enemy.speed

    for bullet in player.bullets:
        bullet.y += bullet.speed

    for rock in rock_rocks:
        rock.y += rock.ys
        rock.x += rock.xs
            
    score_txt.src = "蛋糕数量：" + str(player.score)
    time_txt.src = "剩余时间：" + str(math.floor(time_one - (time.time() - start_time)))

#背景函数
def bg_run():
    window.clear()
    #防护罩实现，跟随飞机改变大小

    background1.h = 601
    background1.w = 601
    background2.h = 601
    background2.w = 601
    
    background1.y -= 1
    background2.y -= 1
    if background1.y < -300:
        background1.y = 899.5
    if background2.y < -300:
        background2.y = 899.5
    background1.draw()
    background2.draw()

    
#计算得分，删除敌机与子弹 1
def enemy_is_hit():
    try:
        #击中敌机
        for enemy in enemys:
            for bullet in player.bullets:
                p = bullet.collide(enemy) #子弹击中敌机
                p1 = defend.collide(enemy) #保护罩击中敌机
                if p1:
                    enemys.remove(enemy)
                    return True
                elif p:
                    enemys.remove(enemy)
                    player.bullets.remove(bullet)
                    return True
        #击中陨石
        for rock in rock_rocks:
            for bullet in player.bullets:
                p = bullet.collide(rock) #子弹击中敌机
                p1 = defend.collide(rock) #保护罩击中敌机
                if p1:
                    rock_rocks.remove(rock)
                    
                    return True
                elif p:
                    rock_rocks.remove(rock)
                    player.bullets.remove(bullet)
                    
                    return True
        
        return  False
    except:
        pass


def remove(dt):
    if len(boom_list) > 0:
        boom_list[:] = []
    #print(len(boom_list))

    if len(boom_rocks) > 0:
        boom_rocks[:] = []


#游戏引擎(发动机)1
def enemy_is_hit_a():
    boom_rock = Sprite("https://r.leaplearner.com/ud/production/958096/IinF.png")
    global bl
    try:
        #击中敌机特效
        for enemy in enemys:
            for bullet in player.bullets:
                p = bullet.collide(enemy) #子弹击中敌机
                p1 = defend.collide(enemy) #保护罩击中敌机
                if p1:
                    boom_a = Sprite("https://r.leaplearner.com/ud/production/958096/6mSw.png")
                    boom_a.src = boom.src
                    boom_a.scale = boom.scale
                    boom_a.x = p1.x
                    boom_a.y = p1.y
                    boom_list.append(boom_a)
                    
                elif p:
                    boom_a = Sprite("https://r.leaplearner.com/ud/production/958096/6mSw.png")
                    balabala = random.randint(1,3)
                    if balabala == 1:
                        boom_a.src = boom1.src
                    elif balabala == 2:
                        boom_a.src = boom2.src
                        
                    #boom_a.src = boom.src
                    boom_a.scale = boom.scale
                    boom_a.x = p.x
                    boom_a.y = p.y
                    boom_list.append(boom_a)
        
        #绘制子弹爆炸效果
        for booms in boom_list:
            booms.draw()

        #子弹优化
        for bullet in player.bullets:
            if bullet.y > window.h:
                player.bullets.remove(bullet)
        #敌机优化
        for enemy in enemys:
            if enemy.y < 0:
                enemys.remove(enemy)
        #击中陨石特效
        for rock in rock_rocks:
             for bullet in player.bullets:
                 p = bullet.collide(rock) #子弹击中陨石
                 p1 = defend.collide(rock) #保护罩击中陨石
                 p2 = player.collide(rock) #飞机撞击陨石
                 if p1:
                     #boom_rock = Sprite("https://r.leaplearner.com/ud/production/958096/IinF.png")
                     boom_rock.scale = rock.scale * 0.04
                     boom_rock.x = p1.x
                     boom_rock.y = p1.y
                     boom_rocks.append(boom_rock)
                     #boom_rock.x = p1.x
                     #boom_rock.y = p1.y
                     #boom_rock.draw()

                 elif p:
                     #boom_rock = Sprite("https://r.leaplearner.com/ud/production/958096/IinF.png")
                     boom_rock.scale = rock.scale * 0.04
                     boom_rock.x = p.x
                     boom_rock.y = p.y
                     boom_rocks.append(boom_rock)
                     #boom_rock.x = p.x
                     #boom_rock.y = p.y
                     #boom_rock.draw()

                 elif p2:
                     #boom_rock = Sprite("https://r.leaplearner.com/ud/production/958096/IinF.png")
                     boom_rock.scale = rock.scale * 0.04
                     boom_rock.x = p2.x
                     boom_rock.y = p2.y
                     boom_rocks.append(boom_rock)
                     #shan.draw()
                     #boom_rock.x = p2.x
                     #boom_rock.y = p2.y
                     #boom_rock.draw()
                     #shan()
                    
        #陨石优化
        for rock in rock_rocks:
            if rock.y < 0:
                rock_rocks.remove(rock)
        for rock in rock_rocks:
            if rock.x > 600:
                rock_rocks.remove(rock)
        
    except:
        #print("c")
        pass

def logic():
    global game_over,time_one
    
    #判断时间是否小于1，进行游戏结束,保护罩除外。
    for enemy in enemys:
        if defend.collide(enemy):
            pass
        elif player.collide(enemy):
            game_over = True
    if math.floor(time_one - (time.time() - start_time)) < 0:
        game_over = True
    #判断是否碰到陨石，扣分
    for rock in rock_rocks:       
        if player.collide(rock):
            rock_rocks.remove(rock)
            player.score -= 2


#课件默认机制定义
def score(dt):
    if enemy_is_hit():  
        player.score += 10

    
#游戏引擎（发动机）2            
def game(dt):
    global game_over
    if(game_over):
        retry()
        stop(bg_run)
        stop(draw)
        stop(enemy_is_hit_a)
        stop(update)
        stop(logic)
        stop(remove)
        stop(retry)
        stop(emit_rock)
        stop(new_enemy)
        stop(emit_bullet)
        stop(game)

    else:
        #bg_run()
        draw()
        enemy_is_hit_a()
        update()
        logic()
                          
run_after(update_bg,1/50)
#设置陨石出现频率
repeat(emit_rock,1.3)
#运行游戏
@window.event
def on_draw():
    game()

repeat(remove,1.5)
#retry_txt.on_press(retry)
#run()
